@@ -1,16 +1,11 @@
 from cg.apps.orderform.orderform_parser import OrderformParser
-from cg.constants import DataDelivery, Workflow
+from cg.constants import DataDelivery
 from cg.exc import OrderFormError
+from cg.models.orders.constants import OrderType
 from cg.models.orders.json_sample import JsonSample
-from cg.models.orders.order import OrderType
 
 
 class JsonOrderformParser(OrderformParser):
-    ACCEPTED_DATA_ANALYSES: list[str] = [
-        Workflow.MIP_DNA,
-        Workflow.FLUFFY,
-        Workflow.BALSAMIC,
-    ]
     NO_VALUE: str = "no_value"
     samples: list[JsonSample] = []
 
@@ -23,7 +18,7 @@ class JsonOrderformParser(OrderformParser):
             raise OrderFormError(f"mixed 'Data Analysis' types: {', '.join(data_analyses)}")
 
         data_analysis: str = data_analyses.pop()
-        if data_analysis in self.ACCEPTED_DATA_ANALYSES:
+        if data_analysis in OrderType.__members__.values():
             return data_analysis
 
         raise OrderFormError(f"Unsupported data_analysis: {data_analyses} for json data")
