@@ -4,7 +4,7 @@ import logging
 import sys
 import traceback
 
-import click
+import rich_click as click
 
 from cg.cli.upload.coverage import upload_coverage
 from cg.cli.upload.delivery_report import upload_delivery_report_to_scout
@@ -25,8 +25,10 @@ from cg.cli.upload.scout import (
     upload_rna_alignment_file_to_scout,
     upload_rna_fusion_report_to_scout,
     upload_rna_junctions_to_scout,
+    upload_rna_omics_to_scout,
     upload_rna_to_scout,
     upload_to_scout,
+    upload_tomte_to_scout,
 )
 from cg.cli.upload.utils import suggest_cases_to_upload
 from cg.cli.upload.validate import validate
@@ -37,12 +39,14 @@ from cg.meta.upload.balsamic.balsamic import BalsamicUploadAPI
 from cg.meta.upload.microsalt.microsalt_upload_api import MicrosaltUploadAPI
 from cg.meta.upload.mip.mip_dna import MipDNAUploadAPI
 from cg.meta.upload.mip.mip_rna import MipRNAUploadAPI
-from cg.meta.upload.raredisease.raredisease import RarediseaseUploadAPI
+from cg.meta.upload.mutant.mutant import MutantUploadAPI
+from cg.meta.upload.nallo.nallo import NalloUploadAPI
 from cg.meta.upload.nf_analysis import NfAnalysisUploadAPI
 from cg.meta.upload.raredisease.raredisease import RarediseaseUploadAPI
+from cg.meta.upload.tomte.tomte import TomteUploadAPI
 from cg.meta.upload.upload_api import UploadAPI
 from cg.models.cg_config import CGConfig
-from cg.store.models import Case
+from cg.store.models import Analysis, Case
 from cg.store.store import Store
 from cg.utils.click.EnumChoice import EnumChoice
 
@@ -83,14 +87,19 @@ def upload(context: click.Context, case_id: str | None, restart: bool):
             upload_api = MipRNAUploadAPI(config_object)
         elif case.data_analysis == Workflow.MICROSALT:
             upload_api = MicrosaltUploadAPI(config_object)
+        elif case.data_analysis == Workflow.NALLO:
+            upload_api = NalloUploadAPI(config_object)
         elif case.data_analysis == Workflow.RAREDISEASE:
             upload_api = RarediseaseUploadAPI(config_object)
+        elif case.data_analysis == Workflow.TOMTE:
+            upload_api = TomteUploadAPI(config_object)
         elif case.data_analysis in {
             Workflow.RNAFUSION,
-            Workflow.TOMTE,
             Workflow.TAXPROFILER,
         }:
             upload_api = NfAnalysisUploadAPI(config_object, case.data_analysis)
+        elif case.data_analysis == Workflow.MUTANT:
+            upload_api = MutantUploadAPI(config_object)
 
         context.obj.meta_apis["upload_api"] = upload_api
         upload_api.upload(ctx=context, case=case, restart=restart)
@@ -111,15 +120,18 @@ def upload_all_completed_analyses(context: click.Context, workflow: Workflow = N
     status_db: Store = context.obj.status_db
 
     exit_code = 0
-    for analysis_obj in status_db.get_analyses_to_upload(workflow=workflow):
-        if analysis_obj.case.analyses[0].uploaded_at is not None:
+    for analysis in status_db.get_analyses_to_upload(workflow=workflow):
+        latest_case_analysis: Analysis = status_db.get_latest_completed_analysis_for_case(
+            analysis.case.internal_id
+        )
+        if latest_case_analysis.uploaded_at is not None:
             LOG.warning(
-                f"Skipping upload for case {analysis_obj.case.internal_id}. "
-                f"Case has been already uploaded at {analysis_obj.case.analyses[0].uploaded_at}."
+                f"Skipping upload for case {analysis.case.internal_id}. "
+                f"Case has been already uploaded at {latest_case_analysis.uploaded_at}."
             )
             continue
 
-        case_id = analysis_obj.case.internal_id
+        case_id = analysis.case.internal_id
         LOG.info(f"Uploading analysis for case: {case_id}")
         try:
             context.invoke(upload, case_id=case_id)
@@ -146,7 +158,10 @@ upload.add_command(upload_observations_to_loqusdb)
 upload.add_command(upload_rna_alignment_file_to_scout)
 upload.add_command(upload_rna_fusion_report_to_scout)
 upload.add_command(upload_rna_junctions_to_scout)
+upload.add_command(upload_rna_omics_to_scout)
+
 upload.add_command(upload_rna_to_scout)
+upload.add_command(upload_tomte_to_scout)
 upload.add_command(upload_to_gens)
 upload.add_command(upload_to_gisaid)
 upload.add_command(upload_to_scout)
