@@ -4,11 +4,18 @@ from enum import IntEnum, StrEnum
 
 
 class SlurmQos(StrEnum):
-    MAINTENANCE: str = "maintenance"
-    LOW: str = "low"
-    NORMAL: str = "normal"
-    HIGH: str = "high"
-    EXPRESS: str = "express"
+    MAINTENANCE = "maintenance"
+    LOW = "low"
+    NORMAL = "normal"
+    HIGH = "high"
+    EXPRESS = "express"
+
+
+class TrailblazerPriority(StrEnum):
+    LOW = "low"
+    NORMAL = "normal"
+    HIGH = "high"
+    EXPRESS = "express"
 
 
 class PriorityTerms(StrEnum):
@@ -20,11 +27,11 @@ class PriorityTerms(StrEnum):
 
 
 class Priority(IntEnum):
-    research: int = 0
-    standard: int = 1
-    priority: int = 2
-    express: int = 3
-    clinical_trials: int = 4
+    research = 0
+    standard = 1
+    clinical_trials = 2
+    priority = 3
+    express = 4
 
     @classmethod
     def priority_to_slurm_qos(cls) -> dict[int, str]:
@@ -38,6 +45,6 @@ class Priority(IntEnum):
 
 
 class SlurmAccount(StrEnum):
-    PRODUCTION: str = "production"
-    DEVELOPMENT: str = "development"
-    STAGE: str = "stage"
+    PRODUCTION = "production"
+    DEVELOPMENT = "development"
+    STAGE = "stage"
