@@ -1,7 +1,7 @@
 """API for tar archiving and extraction on Hasta"""
+
 import logging
 from pathlib import Path
-from typing import List
 
 from cg.constants.extraction import FlowCellExtractionParameters
 from cg.utils import Process
@@ -13,7 +13,8 @@ class TarAPI:
     """Class that uses tar for various archiving and archive extraction functionality"""
 
     def __init__(self, binary_path: str, dry_run: bool = False):
-        self.process: Process = Process(binary=binary_path)
+        self.binary_path: str = binary_path
+        self.process: Process = Process(binary=self.binary_path)
         self.dry_run: bool = dry_run
 
     def run_tar_command(self, command: list) -> None:
@@ -23,7 +24,7 @@ class TarAPI:
         self.process.run_command(command, dry_run=self.dry_run)
 
     @staticmethod
-    def get_extract_file_command(input_file: Path, output_dir: Path) -> List[str]:
+    def get_extract_file_command(input_file: Path, output_dir: Path) -> list[str]:
         """Generates the Tar command for flow cel run directory extraction"""
         extraction_parameters: list = FlowCellExtractionParameters.EXTRACT_FILE.copy()
         extraction_parameters.append(str(input_file))
@@ -33,3 +34,7 @@ class TarAPI:
         extraction_parameters.extend(target_directory_parameters)
         extraction_parameters.append(str(output_dir))
         return extraction_parameters
+
+    def get_compress_cmd(self, input_path: Path) -> str:
+        """Return compression command of input path."""
+        return " ".join([self.binary_path, "-cf", "-", input_path.as_posix()])
