@@ -1,5 +1,6 @@
 """Module for Raredisease Analysis API."""
 
+import csv
 import logging
 from itertools import permutations
 from pathlib import Path
@@ -13,22 +14,27 @@ from cg.clients.chanjo2.models import (
     CoveragePostResponse,
     CoverageSample,
 )
-from cg.constants import DEFAULT_CAPTURE_KIT, Workflow
-from cg.constants.constants import AnalysisType, GenomeVersion
+from cg.constants import Workflow
+from cg.constants.constants import GenomeVersion
 from cg.constants.nf_analysis import (
     RAREDISEASE_COVERAGE_FILE_TAGS,
     RAREDISEASE_COVERAGE_INTERVAL_TYPE,
     RAREDISEASE_COVERAGE_THRESHOLD,
-    RAREDISEASE_METRIC_CONDITIONS,
+    RAREDISEASE_METRIC_CONDITIONS_WES,
+    RAREDISEASE_METRIC_CONDITIONS_WGS,
     RAREDISEASE_PARENT_PEDDY_METRIC_CONDITION,
 )
 from cg.constants.scout import RAREDISEASE_CASE_TAGS, ScoutExportFileName
+from cg.constants.sequencing import SeqLibraryPrepCategory
 from cg.constants.subject import PlinkPhenotypeStatus, PlinkSex
+from cg.constants.tb import AnalysisType
 from cg.meta.workflow.nf_analysis import NfAnalysisAPI
+from cg.models.analysis import NextflowAnalysis
 from cg.models.cg_config import CGConfig
 from cg.models.deliverables.metric_deliverables import MetricsBase, MultiqcDataJson
 from cg.models.raredisease.raredisease import (
     RarediseaseParameters,
+    RarediseaseQCMetrics,
     RarediseaseSampleSheetEntry,
     RarediseaseSampleSheetHeaders,
 )
@@ -49,14 +55,14 @@ class RarediseaseAnalysisAPI(NfAnalysisAPI):
     ):
         super().__init__(config=config, workflow=workflow)
         self.root_dir: str = config.raredisease.root
-        self.nfcore_workflow_path: str = config.raredisease.workflow_path
-        self.references: str = config.raredisease.references
+        self.workflow_bin_path: str = config.raredisease.workflow_bin_path
         self.profile: str = config.raredisease.profile
         self.conda_env: str = config.raredisease.conda_env
         self.conda_binary: str = config.raredisease.conda_binary
-        self.config_platform: str = config.raredisease.config_platform
-        self.config_params: str = config.raredisease.config_params
-        self.config_resources: str = config.raredisease.config_resources
+        self.platform: str = config.raredisease.platform
+        self.params: str = config.raredisease.params
+        self.workflow_config_path: str = config.raredisease.config
+        self.resources: str = config.raredisease.resources
         self.tower_binary_path: str = config.tower_binary_path
         self.tower_workflow: str = config.raredisease.tower_workflow
         self.account: str = config.raredisease.slurm.account
@@ -87,38 +93,32 @@ class RarediseaseAnalysisAPI(NfAnalysisAPI):
         )
         return sample_sheet_entry.reformat_sample_content
 
-    def get_target_bed(self, case_id: str, analysis_type: str) -> str:
-        """
-        Return the target bed file from LIMS and use default capture kit for WGS.
-        """
-        target_bed: str = self.get_target_bed_from_lims(case_id=case_id)
-        if not target_bed:
-            if analysis_type == AnalysisType.WHOLE_GENOME_SEQUENCING:
-                return DEFAULT_CAPTURE_KIT
-            raise ValueError("No capture kit was found in LIMS")
-        return target_bed
+    @property
+    def is_gene_panel_required(self) -> bool:
+        """Return True if a gene panel needs to be created using the information in StatusDB and exporting it from Scout."""
+        return True
 
-    def get_germlinecnvcaller_flag(self, analysis_type: str) -> bool:
-        if analysis_type == AnalysisType.WHOLE_GENOME_SEQUENCING:
-            return True
-        return False
-
-    def get_workflow_parameters(self, case_id: str) -> RarediseaseParameters:
+    def get_built_workflow_parameters(
+        self, case_id: str, dry_run: bool = False
+    ) -> RarediseaseParameters:
         """Return parameters."""
         analysis_type: AnalysisType = self.get_data_analysis_type(case_id=case_id)
-        target_bed: str = self.get_target_bed(case_id=case_id, analysis_type=analysis_type)
-        skip_germlinecnvcaller = self.get_germlinecnvcaller_flag(analysis_type=analysis_type)
+        target_bed_file: str = self.get_target_bed_from_lims(case_id=case_id) or ""
         outdir = self.get_case_path(case_id=case_id)
+        sample_id_map: Path = self.get_sample_name_mapping_csv_path(case=case_id)
+        # Build the sample_id_map path
+        if not dry_run:
+            self.export_customer_internal_mapping_csv(case=case_id, output_path=sample_id_map)
 
         return RarediseaseParameters(
-            local_genomes=str(self.references),
             input=self.get_sample_sheet_path(case_id=case_id),
             outdir=outdir,
             analysis_type=analysis_type,
-            target_bed=Path(self.references, target_bed).as_posix(),
+            target_bed_file=target_bed_file,
             save_mapped_as_cram=True,
-            skip_germlinecnvcaller=skip_germlinecnvcaller,
             vcfanno_extra_resources=f"{outdir}/{ScoutExportFileName.MANAGED_VARIANTS}",
+            vep_filters_scout_fmt=f"{outdir}/{ScoutExportFileName.PANELS}",
+            sample_id_map=sample_id_map,
         )
 
     @staticmethod
@@ -151,27 +151,36 @@ class RarediseaseAnalysisAPI(NfAnalysisAPI):
         """Return True if a managed variants needs to be exported from Scout."""
         return True
 
-    @property
-    def root(self) -> str:
-        return self.config.raredisease.root
-
     def write_managed_variants(self, case_id: str, content: list[str]) -> None:
         self._write_managed_variants(out_dir=Path(self.root, case_id), content=content)
 
     def get_managed_variants(self, case_id: str) -> list[str]:
         """Create and return the managed variants."""
-        return self._get_managed_variants(genome_build=self.get_genome_build(case_id=case_id))
+        return self._get_managed_variants(
+            genome_build=self.get_gene_panel_genome_build(case_id=case_id)
+        )
 
     def get_workflow_metrics(self, sample_id: str) -> dict:
         """Return Raredisease workflow metric conditions for a sample."""
         sample: Sample = self.status_db.get_sample_by_internal_id(internal_id=sample_id)
         if "-" not in sample_id:
-            metric_conditions: dict[str, dict[str, Any]] = RAREDISEASE_METRIC_CONDITIONS.copy()
-            self.set_order_sex_for_sample(sample, metric_conditions)
+            metric_conditions: dict[str, dict[str, Any]] = (
+                self.get_metric_conditions_by_prep_category(sample_id=sample.internal_id)
+            )
+            self.set_order_sex_for_sample(sample=sample, metric_conditions=metric_conditions)
         else:
             metric_conditions = RAREDISEASE_PARENT_PEDDY_METRIC_CONDITION.copy()
         return metric_conditions
 
+    def get_metric_conditions_by_prep_category(self, sample_id: str) -> dict:
+        sample: Sample = self.status_db.get_sample_by_internal_id(internal_id=sample_id)
+        if (
+            sample.application_version.application.analysis_type
+            == SeqLibraryPrepCategory.WHOLE_GENOME_SEQUENCING
+        ):
+            return RAREDISEASE_METRIC_CONDITIONS_WGS.copy()
+        return RAREDISEASE_METRIC_CONDITIONS_WES.copy()
+
     def _get_sample_pair_patterns(self, case_id: str) -> list[str]:
         """Return sample-pair patterns for searching in MultiQC."""
         sample_ids: list[str] = list(self.status_db.get_sample_ids_by_case_id(case_id=case_id))
@@ -193,7 +202,7 @@ class RarediseaseAnalysisAPI(NfAnalysisAPI):
                 metric_id=pair_sample_ids,
             )
 
-    def get_multiqc_json_metrics(self, case_id: str) -> list[MetricsBase]:
+    def get_raredisease_multiqc_json_metrics(self, case_id: str) -> list[MetricsBase]:
         """Return a list of the metrics specified in a MultiQC json file."""
         multiqc_json: MultiqcDataJson = self.get_multiqc_data_json(case_id=case_id)
         metrics = []
@@ -215,9 +224,16 @@ class RarediseaseAnalysisAPI(NfAnalysisAPI):
         metrics = self.get_deduplicated_metrics(metrics=metrics)
         return metrics
 
+    def create_metrics_deliverables_content(self, case_id: str) -> dict[str, list[dict[str, Any]]]:
+        """Create the content of a Raredisease metrics deliverables file."""
+        metrics: list[MetricsBase] = self.get_raredisease_multiqc_json_metrics(case_id=case_id)
+        self.ensure_mandatory_metrics_present(metrics=metrics)
+        return {"metrics": [metric.dict() for metric in metrics]}
+
     @staticmethod
     def set_order_sex_for_sample(sample: Sample, metric_conditions: dict) -> None:
         metric_conditions["predicted_sex_sex_check"]["threshold"] = sample.sex
+        metric_conditions["gender"]["threshold"] = sample.sex
 
     def get_sample_coverage_file_path(self, bundle_name: str, sample_id: str) -> str | None:
         """Return the Raredisease d4 coverage file path."""
@@ -234,7 +250,7 @@ class RarediseaseAnalysisAPI(NfAnalysisAPI):
         self, case_id: str, sample_id: str, gene_ids: list[int]
     ) -> CoverageMetrics | None:
         """Return sample coverage metrics from Chanjo2."""
-        genome_version: GenomeVersion = self.get_genome_build()
+        genome_version: GenomeVersion = self.get_genome_build(case_id)
         coverage_file_path: str | None = self.get_sample_coverage_file_path(
             bundle_name=case_id, sample_id=sample_id
         )
@@ -255,3 +271,31 @@ class RarediseaseAnalysisAPI(NfAnalysisAPI):
     def get_scout_upload_case_tags(self) -> dict:
         """Return Raredisease Scout upload case tags."""
         return RAREDISEASE_CASE_TAGS
+
+    def get_genome_build(self, case_id: str) -> GenomeVersion:
+        """Return reference genome for a raredisease case. Currently fixed for hg19."""
+        return GenomeVersion.HG19
+
+    def parse_analysis(self, qc_metrics_raw: list[MetricsBase], **kwargs) -> NextflowAnalysis:
+        """Parse Nextflow output analysis files and return an analysis model."""
+        qc_metrics_model = RarediseaseQCMetrics
+        return super().parse_analysis(
+            qc_metrics_raw=qc_metrics_raw, qc_metrics_model=qc_metrics_model, **kwargs
+        )
+
+    def get_sample_name_mapping_csv_path(self, case: str) -> Path:
+        """Return the path to the CSV file containing the mapping between sample names and internal ids."""
+        return Path(self.get_case_path(case), f"{case}_customer_internal_mapping.csv")
+
+    def export_customer_internal_mapping_csv(self, case: str, output_path: Path):
+        """Export a CSV file mapping customer sample names to internal sample IDs."""
+        LOG.info(f"Exporting customer internal mapping CSV for case {case} to {output_path}")
+        with output_path.open("w", newline="") as csvfile:
+            writer = csv.writer(csvfile)
+            writer.writerow(
+                ["customer_id", "internal_id"]
+            )  # this is the header expected by the pipeline
+            for link in self.status_db.get_case_by_internal_id(case).links:
+                customer_sample_name = link.sample.name
+                internal_id = link.sample.internal_id
+                writer.writerow([customer_sample_name, internal_id])
