@@ -8,12 +8,7 @@ from typing import Callable, Iterator
 from sqlalchemy.orm import Query
 
 from cg.constants import SequencingRunDataAvailability, Workflow
-from cg.constants.constants import (
-    DNA_WORKFLOWS_WITH_SCOUT_UPLOAD,
-    CaseActions,
-    CustomerId,
-    SampleType,
-)
+from cg.constants.constants import DNA_WORKFLOWS_WITH_SCOUT_UPLOAD, CustomerId, SampleType
 from cg.constants.priority import SlurmQos
 from cg.constants.sequencing import DNA_PREP_CATEGORIES, SeqLibraryPrepCategory
 from cg.exc import (
@@ -121,18 +116,6 @@ class ReadHandler(BaseHandler):
             cases=cases_query, filter_functions=[CaseFilter.BY_ENTRY_ID], entry_id=entry_id
         ).first()
 
-    def has_active_cases_for_sample(self, internal_id: str) -> bool:
-        """Check if there are any active cases for a sample."""
-        sample = self.get_sample_by_internal_id(internal_id=internal_id)
-        active_actions = ["analyze", "running"]
-
-        for family_sample in sample.links:
-            case: Case = self.get_case_by_entry_id(entry_id=family_sample.case_id)
-            if case.action in active_actions:
-                return True
-
-        return False
-
     def get_application_by_case(self, case_id: str) -> Application:
         """Return the application of a case."""
 
@@ -568,19 +551,6 @@ class ReadHandler(BaseHandler):
         ).all()
         return pools + samples
 
-    def get_case_sample_link(self, case_internal_id: str, sample_internal_id: str) -> CaseSample:
-        """Return a case-sample link between a family and a sample."""
-        filter_functions: list[CaseSampleFilter] = [
-            CaseSampleFilter.SAMPLES_IN_CASE_BY_INTERNAL_ID,
-            CaseSampleFilter.CASES_WITH_SAMPLE_BY_INTERNAL_ID,
-        ]
-        return apply_case_sample_filter(
-            filter_functions=filter_functions,
-            case_samples=self._get_join_case_sample_query(),
-            case_internal_id=case_internal_id,
-            sample_internal_id=sample_internal_id,
-        ).first()
-
     def new_invoice_id(self) -> int:
         """Fetch invoices."""
         query: Query = self._get_query(table=Invoice)
@@ -1099,10 +1069,6 @@ class ReadHandler(BaseHandler):
         )
         return records.order_by(Sample.prepared_at).all()
 
-    def get_cases_with_analyzes(self) -> Query:
-        """Return all cases in the database with an analysis."""
-        return self._get_outer_join_cases_with_analyses_query()
-
     def get_cases_with_samples(self) -> Query:
         """Return all cases in the database with samples."""
         return self._get_join_cases_with_samples_query()
