@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import List, Optional, Callable
+from typing import Callable
 
 from sqlalchemy.orm import Query
 
@@ -14,11 +14,11 @@ def filter_collaboration_by_internal_id(collaborations: Query, internal_id: str,
 class CollaborationFilter(Enum):
     """Define Collaboration filter functions."""
 
-    FILTER_BY_INTERNAL_ID: Callable = filter_collaboration_by_internal_id
+    BY_INTERNAL_ID: Callable = filter_collaboration_by_internal_id
 
 
 def apply_collaboration_filter(
-    collaborations: Query, filter_functions: List[Callable], internal_id: Optional[str] = None
+    collaborations: Query, filter_functions: list[Callable], internal_id: str | None = None
 ) -> Query:
     """Apply filtering functions and return filtered results."""
     for function in filter_functions:
