@@ -1,6 +1,8 @@
-from typing import Optional, List, Callable
 from enum import Enum
+from typing import Callable
+
 from sqlalchemy.orm import Query
+
 from cg.store.models import Invoice
 
 
@@ -20,9 +22,9 @@ def filter_invoices_not_invoiced(invoices: Query, **kwargs) -> Query:
 
 
 def apply_invoice_filter(
-    filter_functions: List[str],
+    filter_functions: list[str],
     invoices: Query,
-    entry_id: Optional[int] = None,
+    entry_id: int | None = None,
 ) -> Query:
     """Apply filtering functions to the invoice queries and return filtered results."""
 
@@ -34,6 +36,6 @@ def apply_invoice_filter(
 class InvoiceFilter(Enum):
     """Define Invoice filter functions."""
 
-    FILTER_BY_INVOICE_ID: Callable = filter_invoices_by_invoice_id
-    FILTER_BY_INVOICED: Callable = filter_invoices_invoiced
-    FILTER_BY_NOT_INVOICED: Callable = filter_invoices_not_invoiced
+    BY_INVOICE_ID: Callable = filter_invoices_by_invoice_id
+    BY_INVOICED: Callable = filter_invoices_invoiced
+    BY_NOT_INVOICED: Callable = filter_invoices_not_invoiced
