@@ -1,6 +1,8 @@
 from enum import Enum
-from typing import Callable, List, Optional
+from typing import Callable
+
 from sqlalchemy.orm import Query
+
 from cg.store.models import Panel
 
 
@@ -12,13 +14,13 @@ def filter_panel_by_abbrev(panels: Query, abbreviation: str, **kwargs) -> Query:
 class PanelFilter(Enum):
     """Define Panel filter functions."""
 
-    FILTER_BY_ABBREVIATION: Callable = filter_panel_by_abbrev
+    BY_ABBREVIATION: Callable = filter_panel_by_abbrev
 
 
 def apply_panel_filter(
     panels: Query,
-    filters: List[PanelFilter],
-    abbreviation: Optional[str] = None,
+    filters: list[PanelFilter],
+    abbreviation: str | None = None,
 ) -> Query:
     """Apply filtering functions and return filtered results."""
     for filter_function in filters:
